@@ -5,6 +5,7 @@ This class handles 3d vectors
 """
 
 import math
+import numpy
 
 # class interface
 
@@ -14,6 +15,10 @@ class VectorThree(object):
         self.B = b
         self.C = c        
         self.Valid = True
+        self.npy = numpy.zeros((3))
+        self.npy[0] = a
+        self.npy[1] = b
+        self.npy[2] = c
 
     def from_coords(self, coords):    
         coords = coords.strip()
